Session
=======

A session both launches a new EDB API server and creates a channel connection to this server.
Once these actions are completed, all EDB API function calls are processed using this channel.

Functions
---------

.. currentmodule:: ansys.edb.core.session

.. autosummary::
   :toctree: _autosummary

   attach_session
   launch_session
   session
